netapp_ontap.models.azure_key_vault_state API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.azure_key_vault_state`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AzureKeyVaultStateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AzureKeyVaultState object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `available GET`

    Set to true when an AKV wrapped internal key is present on all nodes of the cluster.

  `code GET`

    Code corresponding to the status message. Returns a 0 if AKV wrapped key is available on all nodes in the cluster.

    Example: 346758

  `message GET`

    Error message set when AKV wrapped key availability on cluster is false.

    Example: AKV wrapped internal key is missing on nodes - node1, node2.